import { __assign } from './../external/tslib/tslib.es6.js';
import React, { useState, useRef, useEffect, createRef } from 'react';
import { useClickOutside, useForkRef } from '@highlight-ui/utils-hooks';
import classnames from 'classnames';
import { Tag } from '@highlight-ui/tag';
import { Typography } from '@highlight-ui/typography';
import { parseMetadata, suffixMetadata } from '@highlight-ui/utils-commons';
import styles from './TagInput.module.scss.js';

var getTagsShownNumber = function (tagElements, containerElement, suffixRef) {
  if (!tagElements.length) return 0;
  if (!containerElement.current) return 0;
  var prefixWidth = suffixRef.current ? suffixRef.current.offsetWidth + 24 : 0;
  var maxWidth = containerElement.current.offsetWidth - 40 - prefixWidth;
  var value = tagElements.slice(1).reduce(function (acc, item) {
    if (!item.current) return acc;

    if (maxWidth > acc.totalWidth + item.current.offsetWidth + 4) {
      return {
        items: acc.items + 1,
        totalWidth: acc.totalWidth + item.current.offsetWidth + 4
      };
    }

    return {
      items: acc.items,
      totalWidth: acc.totalWidth + item.current.offsetWidth
    };
  }, {
    items: 1,
    totalWidth: tagElements[0].current ? tagElements[0].current.offsetWidth + 4 : 0
  });
  return value.items;
};

var TagInput = /*#__PURE__*/React.forwardRef(function (_a, ref) {
  var _b;

  var tags = _a.tags,
      onInputClick = _a.onInputClick,
      onInputChange = _a.onInputChange,
      onTagAdd = _a.onTagAdd,
      onTagRemove = _a.onTagRemove,
      suffix = _a.suffix,
      className = _a.className,
      metadata = _a.metadata,
      selectRef = _a.selectRef;

  var _c = useState(''),
      inputValue = _c[0],
      setInputValue = _c[1];

  var _d = useState(false),
      isFocused = _d[0],
      setFocus = _d[1];

  var _e = useState([]),
      elRefs = _e[0],
      setElRefs = _e[1];

  var inputRef = useRef(null);
  var innerRef = useRef(null);
  var suffixRef = useRef(null);

  var clearInput = function () {
    setInputValue('');

    if (onInputChange) {
      onInputChange('');
    }
  }; // TODO: refactor and remove selectRef from TagInput [PPUI-2030]


  var clickOutsideRef = useClickOutside(function (event) {
    var _a;

    setFocus(false);

    if (inputValue) {
      if (!selectRef || selectRef && !((_a = selectRef.current) === null || _a === void 0 ? void 0 : _a.contains(event.target))) {
        onTagAdd(inputValue);
      }

      clearInput();
    }
  });
  var containerRef = useForkRef([ref, clickOutsideRef, innerRef]);

  var _f = useState(0),
      tagsShownNumber = _f[0],
      setTagsShownNumber = _f[1];

  useEffect(function () {
    setElRefs(function (prevState) {
      return Array(tags.length).fill(0).map(function (_, i) {
        return prevState[i] || /*#__PURE__*/createRef();
      });
    });
  }, [tags]);
  useEffect(function () {
    if (elRefs && innerRef) {
      setTagsShownNumber(getTagsShownNumber(elRefs, innerRef, suffixRef));
    }
  }, [elRefs, innerRef]);
  return /*#__PURE__*/React.createElement("div", __assign({
    className: classnames(styles.container, className)
  }, parseMetadata(metadata)), /*#__PURE__*/React.createElement("div", {
    role: "none",
    onClick: function (e) {
      var _a;

      e.stopPropagation();
      e.preventDefault();
      (_a = inputRef.current) === null || _a === void 0 ? void 0 : _a.focus();
    },
    ref: containerRef,
    className: classnames(styles.inputOutline, (_b = {}, _b[styles.focused] = isFocused, _b))
  }, tags.map(function (tag, index) {
    var _a;

    return (
      /*#__PURE__*/
      // eslint-disable-next-line react/no-array-index-key
      React.createElement(React.Fragment, {
        key: index
      }, /*#__PURE__*/React.createElement(Tag, __assign({}, tag, {
        metadata: suffixMetadata(metadata, "tag-" + index),
        ref: elRefs[index],
        className: classnames(styles.tag, (_a = {}, _a[styles.isHidden] = !isFocused && index >= tagsShownNumber, _a)),
        onRemove: function (e) {
          e.stopPropagation();
          onTagRemove(tag, index);
        }
      })), !isFocused && index === tagsShownNumber - 1 && tags.length > tagsShownNumber && /*#__PURE__*/React.createElement(Tag, {
        className: styles.additionalTags,
        text: "+" + (tags.length - tagsShownNumber)
      }))
    );
  }), /*#__PURE__*/React.createElement("input", {
    ref: inputRef,
    className: styles.inputElement,
    value: inputValue,
    onKeyDown: function (event) {
      var value = event.currentTarget.value;

      if (value) {
        if (event.key === 'Enter' || event.key === 'Tab' || event.key === ',') {
          onTagAdd(value);
          clearInput();
        }
      }
    },
    onChange: function (event) {
      var input = event.target.value;

      if (input !== ',') {
        setInputValue(input);

        if (onInputChange) {
          onInputChange(input);
        }
      }
    },
    onFocus: function () {
      if (!isFocused) {
        setFocus(true);

        if (onInputClick) {
          onInputClick();
        }
      }
    }
  }), suffix && /*#__PURE__*/React.createElement(Typography, {
    ref: suffixRef,
    variant: "caption-1",
    className: styles.suffix
  }, suffix)));
});
export { TagInput as default };
//# sourceMappingURL=TagInput.js.map
