import React, { useState, useCallback } from 'react';
import { Select } from '@highlight-ui/select';
import { suffixMetadata } from '@highlight-ui/utils-commons';
import TagInput from './TagInput.js';

function TagPickerWithRef(_a, ref) {
  var tags = _a.tags,
      onInputChange = _a.onInputChange,
      onTagAdd = _a.onTagAdd,
      onTagRemove = _a.onTagRemove,
      options = _a.options,
      className = _a.className,
      metadata = _a.metadata,
      suffix = _a.suffix;

  var _b = useState(''),
      highlightedText = _b[0],
      setHighlightedText = _b[1];

  var handleOnInputChange = useCallback(function (input) {
    setHighlightedText(input);

    if (onInputChange) {
      onInputChange(input);
    }
  }, [onInputChange]);
  var renderTriggerCallback = useCallback(function (_a) {
    var onClick = _a.onClick,
        triggerRef = _a.ref,
        selectRef = _a.selectRef;
    return /*#__PURE__*/React.createElement(TagInput, {
      metadata: suffixMetadata(metadata, 'tag-input'),
      tags: tags,
      onInputClick: onClick,
      onInputChange: handleOnInputChange,
      onTagAdd: onTagAdd,
      onTagRemove: onTagRemove,
      suffix: suffix,
      ref: triggerRef,
      selectRef: selectRef
    });
  }, [handleOnInputChange, metadata, onTagAdd, onTagRemove, suffix, tags]);
  return /*#__PURE__*/React.createElement(Select, {
    ref: ref,
    className: className,
    metadata: metadata,
    renderTrigger: renderTriggerCallback,
    closeOnSelect: true,
    highlightedText: highlightedText,
    searchable: false,
    options: options,
    renderEmptyState: function () {
      return null;
    },
    onSelect: function (option) {
      return onTagAdd(option[0].label);
    }
  });
}

TagPickerWithRef.displayName = 'TagPicker';
var TagPicker = /*#__PURE__*/React.forwardRef(TagPickerWithRef);
export { TagPicker };
//# sourceMappingURL=TagPicker.js.map
